@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2012 Emweb bvba
+ * Copyright (C) 2012 Emweb bv, Herent, Belgium
  *
  * See the LICENSE file for terms of use.
  */
@@ -10,7 +10,7 @@
 
 #include "Sample.h"
 
-#include <Wt/WTemplate>
+#include <Wt/WTemplate.h>
 
 class TopicTemplate : public Wt::WTemplate
 {
@@ -18,13 +18,13 @@ public:
   TopicTemplate(const char *trKey);
 
   virtual void resolveString(const std::string& varName,
-			     const std::vector<Wt::WString>& args,
-			     std::ostream& result);
+                             const std::vector<Wt::WString>& args,
+                             std::ostream& result);
 
 private:
   std::string docUrl(const std::string& className);
   std::string getString(const std::string& varName);
-  
+
   static std::string escape(const std::string& name);
 };
 
